From 120e4ca11f021fa2d7e7abf57187c2db71942302 Mon Sep 17 00:00:00 2001
From: Bob Vergauwen <emacs@vergauwen.me>
Date: Fri, 29 Jul 2022 14:28:21 +0200
Subject: [PATCH] lisp/ox-latex: Omit empty date

* lisp/ox-latex.el: (org-latex-template): When no date is provided or
the export option date is nil, the empty '\date{}' string is no
longer included in the exported latex document.

The default behaviour for ox-latex was to include an empty date line as
'\date{}'.  This empty date line can affect more complex latex templates
when the date is for example set by the template on compilation, or when
the date command is overwritten entirely.  In this new patch, the date
line is omitted from the exported document.

TINYCHANGE
---
 lisp/ox-latex.el | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/lisp/ox-latex.el b/lisp/ox-latex.el
index 1ed988917..129b2dbf0 100644
--- a/lisp/ox-latex.el
+++ b/lisp/ox-latex.el
@@ -1977,7 +1977,8 @@ holding export options."
 	     ((or author email) (format "\\author{%s}\n" (or author email)))))
      ;; Date.
      (let ((date (and (plist-get info :with-date) (org-export-get-date info))))
-       (format "\\date{%s}\n" (org-export-data date info)))
+       (cond date
+             (format "\\date{%s}\n" (org-export-data date info))))
      ;; Title and subtitle.
      (let* ((subtitle (plist-get info :subtitle))
 	    (formatted-subtitle
--
2.30.1 (Apple Git-130)
